import { RouteProps } from "config/routes/types";

const formatRoutes = ({ routes = [], prefix = null }) => {
  return routes.map((route) => {
    const { name, path, routes: children,...rest } = route;
    return {
      name,
      path: route.routes?.length ? path : `/${prefix}${path}`,
      routes: formatRoutes({ routes: children, prefix }),
      ...rest,
    };
  });
}


// ?------------ 视频模块路由 -----------------
const videoRoutes = [
  {
    name: '实时监控',
    path: '/realTimeMonitor',
    component: '@/pages/RealTimeMonitor',
  },
  {
    name: '预警记录',
    path: '/alarmManage',
    routes: [
      {
        name: '预警记录',
        path: '/alarmManage/AlarmRecord',
        component: '@/pages/AlarmRecord',
      },
      {
        name: '误报库',
        path: '/alarmManage/errorLibrary',
        component: '@/pages/errorLibrary',
      },
    ]
  },
  {
    name: '人流量统计',
    path: '/trafficCount',
    component: '@/pages/TrafficCount',
  },
]

const algorithmRoutes = [
  {
    name: '算法管理',
    path: '/algorithmManage/algorithmManage',
    routes: [
      {
        name: '算法配置',
        path: '/algorithmManage/algorithmConfig',
        component: '@/pages/AlgorithmManage',
      },
      {
        name: '时间模版',
        path: '/algorithmManage/timeTemplate',
        component: '@/pages/BoxManage/TimeTemplate',
      },
    ],
  },
  {
    name: '摄像头管理',
    path: '/cameraManage',
    component: '@/pages/cameraManage/index',
  },
  {
    name: '系统配置',
    path: '/systemConfig',
    routes: [
      // {
      //   name: '电子地图配置',
      //   path: '/systemConfig/mapConfig',
      //   component: '@/pages/SystemConfig/MapConfig',
      // },
      {
        name: '修改密码',
        path: '/systemConfig/editPassword',
        component: '@/pages/SystemConfig/EditPassword',
      },
      {
        name: '组织管理',
        path: '/systemConfig/organizeManage',
        component: '@/pages/SystemConfig/OrganizeManage',
      },
      {
        name: '角色管理',
        path: '/systemConfig/roleManage',
        component: '@/pages/SystemConfig/RoleManage',
      },
      {
        name: '用户管理',
        path: '/systemConfig/userManage',
        component: '@/pages/SystemConfig/UserManage',
      },
    ],
  },
]

const routes = [
  {
    name: '首页',
    path: '/home',
    hideInMenu: true,
    component: '@/pages/home',
  },
  {
    name: '登录',
    path: '/login',
    hideInMenu: true,
    component: '@/pages/login',
  },
  {
    name: '未找到页面',
    path: '/*',
    layout: false,
    hideInMenu: true,
    component: '@/pages/404',
  },
  {
    name: '无权限页面',
    path: '/403',
    layout: false,
    hideInMenu: true,
    component: '@/pages/403',
  },
  
  {
    name: '修改密码',
    path: '/video/editPassword',
    component: '@/pages/EditPassword',
    hideInMenu: true,
  },
  ...formatRoutes({ routes: videoRoutes, prefix: 'video' }),
  ...formatRoutes({ routes: algorithmRoutes, prefix: 'algorithm'})
];

export default routes;

