// import { SettingOutlined, ShopOutlined } from '@ant-design/icons';
import logo from '@/assets/logo.png';
import {
  MicroAppLink,
  Outlet,
  history,
  useLocation,
  useModel,
} from '@umijs/max';
import { px2remTransformer, StyleProvider } from '@ant-design/cssinjs';
import { ProConfigProvider, ProLayout, ProSettings } from '@ant-design/pro-components';
import React, { useState } from 'react';
import slave from '@zhst/slave';
import routes from './defaultRoutes'
import styles from './index.less';
import { BankOutlined } from '@ant-design/icons';
import { Dropdown, App } from 'antd';

const Layout = (props) => {
  const [settings] = useState<Partial<ProSettings> | undefined>({
    layout: 'top',
  });
  const location = useLocation();
  const [pathname, setPathname] = useState('')
  const px2rem = px2remTransformer({
    rootValue: ROOT_FONT_SIZE, // 32px = 1rem; @default 16
  });
  const { userInfo = {}, hasAuth } = useModel('user') || {};

  console.log(userInfo)
  
  return (
    <div className={styles.layout}>
      <App>
        <StyleProvider transformers={[px2rem]} hashPriority='high'>
          <ProConfigProvider hashed={false}>
              <ProLayout
                route={{
                  path: '/',
                  routes
                }}
                title="明眸智能分析系统"
                logo={logo}
                token={{
                  header: {
                    heightLayoutHeader: 60,
                    colorBgHeader: '#313c5d',
                    colorHeaderTitle: '#fff',
                    colorTextMenu: '#fff',
                    colorTextMenuSelected: '#fff',
                    colorTextMenuActive: '#fff',
                    colorBgMenuItemSelected: '#23ACB2',
                    colorBgMenuItemHover: '#23ACB2',
                    colorTextRightActionsItem: '#fff',
                    colorTextMenuSecondary: '#000',
                  },
                }}
                menu={{}}
                menuProps={{
                  mode: 'horizontal',
                }}
                avatarProps={{
                  src: userInfo?.username || '-',
                  size: 'small',
                  title: userInfo?.username || '-',
                  render: (props, dom) => {
                    return (
                      <Dropdown
                        menu={{
                          items: [
                            {
                              key: 'changepassword',
                              label: '修改密码',
                              onClick: () => {
                                history.push('/algorithm/editPassword');
                                setPathname('/algorithm/editPassword')
                              },
                            },
                            {
                              key: 'logout',
                              label: <span style={{ color: 'red' }}>退出登录</span>,
                              onClick: () => slave.logOut(`${COMMON_URL || location.origin}/material/login`),
                            },
                          ],
                        }}
                      >
                        {dom}
                      </Dropdown>
                    );
                  },
                }}
                actionsRender={() => {
                  return [
                    // <Badge dot key="alarm">
                    //   <IconFont icon="icon-xiaoxi" size={18} color="#fff" />
                    // </Badge>,
                    // <MicroAppLink name="algorithm" to="/" key="algorithm">
                    //   <div style={{ cursor: 'pointer' }}>
                    //     <BankOutlined
                    //       style={{ fontSize: 18, color: '#fff', marginRight: 5 }}
                    //     />
                    //     AI算法仓平台
                    //   </div>
                    // </MicroAppLink>
                  ];
                }}
                location={{
                  pathname,
                }}
                menuItemRender={(item: { path: string }, dom) => (
                  <div
                    onClick={() => {
                      history.push(item.path || '/');
                      setPathname(item.path);
                    }}
                  >
                    {dom}
                  </div>
                )}
                {...settings}
              >
                <Outlet />
              </ProLayout>
          </ProConfigProvider>
        </StyleProvider>
      </App>
    </div>
  );
};

export default Layout;
